pub enum MirEvalError<'db> {
Show 16 variants
ConstEvalError(String, Box<ConstEvalError<'db>>),
LayoutError(LayoutError, StoredTy),
TargetDataLayoutNotAvailable(TargetLoadError),
UndefinedBehavior(String),
Panic(String),
MirLowerError(FunctionId, MirLowerError<'db>),
MirLowerErrorForClosure(InternedClosureId<'db>, MirLowerError<'db>),
TypeIsUnsized(StoredTy, &'static str),
NotSupported(String),
InvalidConst,
InFunction(Box<MirEvalError<'db>>, Vec<(Either<FunctionId, InternedClosureId<'db>>, MirSpan, InferBodyId<'db>)>),
ExecutionLimitExceeded,
StackOverflow,
InvalidVTableId(usize),
CoerceUnsizedError(StoredTy),
InternalError(Box<str>),
}Variants
ConstEvalError(String, Box<ConstEvalError<'db>>)
LayoutError(LayoutError, StoredTy)
TargetDataLayoutNotAvailable(TargetLoadError)
UndefinedBehavior(String)
Means that code had undefined behavior. We don’t try to actively detect UB, but if it was detected then use this type of error.
Panic(String)
MirLowerError(FunctionId, MirLowerError<'db>)
MirLowerErrorForClosure(InternedClosureId<'db>, MirLowerError<'db>)
TypeIsUnsized(StoredTy, &'static str)
NotSupported(String)
InvalidConst
InFunction(Box<MirEvalError<'db>>, Vec<(Either<FunctionId, InternedClosureId<'db>>, MirSpan, InferBodyId<'db>)>)
ExecutionLimitExceeded
StackOverflow
InvalidVTableId(usize)
FIXME: Fold this into InternalError
CoerceUnsizedError(StoredTy)
?
InternalError(Box<str>)
These should not occur, usually indicates a bug in mir lowering.
Implementations
Sourceimpl MirEvalError<'_>
impl MirEvalError<'_>
pub fn pretty_print( &self, f: &mut String, db: &dyn HirDatabase, span_formatter: impl Fn(FileId, TextRange) -> String, display_target: DisplayTarget, ) -> Result<(), Error>
pub fn is_panic(&self) -> Option<&str>